# Security Policy

## Supported Versions

The table below lists which versions of `qiskit-connector` are **actively supported with security updates**.  
We recommend using the latest version to ensure you receive all security patches.

| Version   | Supported          |
|-----------|-------------------|
| 2.2.x     | :white_check_mark: |
| 2.1.x     | :white_check_mark: |
| 2.0.x     | :x:                |
| < 2.0     | :x:                |

> **Note:** Only the latest two minor release series (2.2.x and 2.1.x) are actively maintained. Older versions will not receive security updates.

---

## Reporting a Vulnerability

If you believe you have discovered a security vulnerability in `qiskit-connector`, **please report it responsibly** using one of the methods below:

- **GitHub Security Advisories:**  
  [Open a private security advisory](https://github.com/QComputingSoftware/pypi-qiskit-connector/security/advisories/new) (preferred).

**We asked that you please do NOT file public issues for security problems.**

**Response expectations:**
- You will receive an acknowledgment within **72 hours** of your report.
- We will work with you to investigate and address the issue promptly.
- Once resolved, a security advisory and patched release will be published.

**Thank you for helping keep Qiskit Connector secure for the entire community!**
